@@ -26,14 +26,18 @@ typedef struct FTPWhoEntry_ {
     volatile off_t download_total_size;
     volatile off_t download_current_size;    
     char account[9];
-#ifdef PAGE_SIZE
-# if PAGE_SIZE > 2048
+#if defined(__OpenBSD__) || defined(__MicroBSD__)
+    char filename[1024];
+#else
+# ifdef PAGE_SIZE
+#  if PAGE_SIZE > 2048
     char filename[PAGE_SIZE - 1024];
+#  else
+    char filename[1024];
+#  endif
 # else
     char filename[1024];
 # endif
-#else
-    char filename[1024];
 #endif
 } FTPWhoEntry;
 
